recsyslearn.errors package
==========================

Submodules
----------

recsyslearn.errors.errors module
--------------------------------

.. automodule:: recsyslearn.errors.errors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recsyslearn.errors
   :members:
   :undoc-members:
   :show-inheritance:
